jenkins-bot has submitted this change and it was merged. ( 
https://gerrit.wikimedia.org/r/347322 )

Change subject: NS_IMAGE -> NS_FILE
......................................................................


NS_IMAGE -> NS_FILE

Deprecated since 1.14

Change-Id: I6169fbb3adc241a02f62ff1193196984a43dca57
---
M includes/utility/LinkProvider.class.php
M includes/utility/PageContentProvider.class.php
M maintenance/RenameCategories.php
M maintenance/massedit.php
4 files changed, 5 insertions(+), 5 deletions(-)

Approvals:
  Robert Vogel: Looks good to me, approved
  jenkins-bot: Verified



diff --git a/includes/utility/PageContentProvider.class.php 
b/includes/utility/PageContentProvider.class.php
index 1bbe818..7bdd69e 100644
--- a/includes/utility/PageContentProvider.class.php
+++ b/includes/utility/PageContentProvider.class.php
@@ -272,7 +272,7 @@
                $sError = '';
                try {
                        switch( $oTitle->getNamespace() ) {
-                               case NS_IMAGE:
+                               case NS_FILE:
                                        $oImagePage = ImagePage::newFromTitle( 
$oTitle, $context );
                                        $oImagePage->view(); //Parse to 
OutputPage
                                        break;
diff --git a/maintenance/RenameCategories.php b/maintenance/RenameCategories.php
index 53e64c1..8d35b91 100644
--- a/maintenance/RenameCategories.php
+++ b/maintenance/RenameCategories.php
@@ -123,7 +123,7 @@
 //                                     '/test test/'
 //                             );
 //$namespace_include = array( 10 );
-//$namespace_exclude = array( NS_IMAGE, NS_IMAGE_TALK, NS_MEDIAWIKI, 
NS_MEDIAWIKI_TALK );
+//$namespace_exclude = array( NS_FILE, NS_FILE_TALK, NS_MEDIAWIKI, 
NS_MEDIAWIKI_TALK );
 //$title_include = array( '/Datev/', '/Hauptseite/' );
 //$title_include = array( '|NZ/.*?|' );
 //$title_include = array( '|NZ/.*?|' );
diff --git a/maintenance/massedit.php b/maintenance/massedit.php
index 254baea..e8445ba 100644
--- a/maintenance/massedit.php
+++ b/maintenance/massedit.php
@@ -49,7 +49,7 @@
 
 $namespace_include = array( NS_MAIN );
 //$namespace_include = array( 10 );
-//$namespace_exclude = array( NS_IMAGE, NS_IMAGE_TALK, NS_MEDIAWIKI, 
NS_MEDIAWIKI_TALK );
+//$namespace_exclude = array( NS_FILE, NS_FILE_TALK, NS_MEDIAWIKI, 
NS_MEDIAWIKI_TALK );
 
 #==================
 # TITLE FILTER

diff --git a/includes/utility/LinkProvider.class.php 
b/includes/utility/LinkProvider.class.php
index 2fb6f47..104ba6d 100644
--- a/includes/utility/LinkProvider.class.php
+++ b/includes/utility/LinkProvider.class.php
@@ -125,7 +125,7 @@
 
        /**
         * Creates a WikiText Link in the form of 
"[[NSP:Title|Description]]"
         * and escapes it if the Title is from NS_CATEGORY or NS_IMAGE to aviod
         * parsing problems.
         * @param Title $oTitle The MediaWiki Title object to link to.
         * @param string $sDescription The description part of the link.
@@ -136,7 +136,7 @@
 
                $sWikiLink = '[[';
 
-               if ( in_array( $oTitle->getNamespace(), array( NS_IMAGE, 
NS_CATEGORY ) ) ) {
+               if ( in_array( $oTitle->getNamespace(), array( NS_FILE, 
NS_CATEGORY ) ) ) {
                        $sWikiLink .= ':'; //Prevent file links from being 
@@ -125,7 +125,7 @@
         * Creates a WikiText Link in the form of 
"[[NSP:Title|Description]]"
-        * and escapes it if the Title is from NS_CATEGORY or NS_IMAGE to aviod
+        * and escapes it if the Title is from NS_CATEGORY or NS_FILE to aviod
         * parsing problems.
         * @param Title $oTitle The MediaWiki Title object to link to.
rendered as <img .../> tags and category links as... nothing.
                }
 
-- 
To view, visit https://gerrit.wikimedia.org/r/347322
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: merged
Gerrit-Change-Id: I6169fbb3adc241a02f62ff1193196984a43dca57
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/extensions/BlueSpiceFoundation
Gerrit-Branch: REL1_27
Gerrit-Owner: Robert Vogel <[email protected]>
Gerrit-Reviewer: Robert Vogel <[email protected]>
Gerrit-Reviewer: Umherirrender <[email protected]>
Gerrit-Reviewer: jenkins-bot <>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to